package com.tencent.qqmusic.third;

import com.tencent.qqmusic.third.IQQMusicCallbackForThird;
import com.tencent.qqmusic.third.SongInfoForThird;

interface IQQMusicServiceForThird
{
	//以下为播放相关
    //表示是否正在播放
    boolean isPlayingFromUI();
    //停止播放
    void stop();
    //暂停播放
    void pause();
    //重新开始播放
    void play();
    //上一首
    void prev();
    //下一首
    void next();
    //接着暂停播放
    void resume();
    //拖动播放进度播放可以跳到具体时间
    long seek(long pos);
  	//获取状态相关
  	//得到播放状态,0表示播放，1表示暂停，2表示停止，3表示关闭，4表示连接中针对网络在线播放的，5表示下载中同样针对网络在先播放的，6表示暂停下载中，7表示获取播放列表，8表示空
    int getPlayState();
    //得到播放总时长
    long getDuration();
    //得到当前播放的时长
    long getCurrTime();
    //得到当前下载了多少
    long getBufferLength();
    //得到需要下载的总长度
    long getTotalLength(); 
    //得到播放模式，单首循环、列表循环和列表随机,103为列表循环，101为单曲循环，105为列表随机 
    int getPlayMode();

    //得到当前播放歌曲的信息	
	SongInfoForThird getPlaySong();
	
	//得到当前播放的是播放列表中的第几首歌曲
	int getPlayPos();
	
	//得到当前的播放列表
	SongInfoForThird[] getPlayList();
	
	//得到播放歌曲的歌词本地文件路径
	String getPlaySongLyricPath();
	
	//得到播放的歌曲的专辑路径，mini为true表示取小专辑图，否则是大专辑图
	String getPlaySongAlbumPath(boolean mini);

	//得到播放的歌曲的url，mini 为 true 小图，true 大图, 该地址属于网络下载地址,可以通过loadImageByUrl加载本地图片
    String getPlaySongAlbumUrl(boolean mini);

	//得到播放列表中的歌曲的专辑路径，mini为true表示取小专辑图，否则是大专辑图，pos表示这首歌在整个列表中的具体位置	
	String getListPoseSongAlbumPath(boolean mini, int pos);
	
	//得到播放列表中的歌曲的专辑url，mini为true表示取小专辑图，否则是大专辑图，pos表示这首歌在整个列表中的具体位置, 该地址属于网络下载地址,可以通过loadImageByUrl加载本地图片
	String getListPoseSongAlbumUrl(boolean mini, int pos);
	
	//根据一个路径去对应的专辑图，因为我们的专辑图保存时候加密了必须通过这个方法得到对应图片，isARBG表示是否用arbg方式显示，width、height是要得到的图片的宽和高
	Bitmap getPlaySongAlbumBitmap(boolean isARBG, int width, int height, String filePath);
	
	//播放网络歌曲的时候第一部分还没有下载完成时候的缓冲数据0到100，这个不一定能用到
    int getBufferPercent();
      
    //播放列表中的第几首歌曲，比如点击列表中第十首歌曲，就会pos传9，会播放这首歌曲  
    void playPos(int pos);
  
    //切换播放模式，单首循环、列表循环和列表随机 ,103为列表循环，101为单曲循环，105为列表随机 ，三个顺序一定为103,101,105可以做到和qq音乐同步
    void setPlayMode(int mode);
    //注册观察者，回调函数
    void registerCallback(IQQMusicCallbackForThird cb);
    //解注册观察者，回调函数
    void unRegisterCallback(IQQMusicCallbackForThird cb);
    
    //获得qq音乐中内部的链接情况
    int getConnectionState();
    //请求歌词,通过回调接口 onLyricLoaded 返回, 该方法慎用, onLyricLoaded 会在切歌成功后加载词时主动回调, requestLyric应该在初始化或服务重绑时调用,其它时候不应使用,否则会引起严重后果
    void requestLyric();
    //使用URL加载图片, onImageLoaded 中返回
    void loadImageByUrl(String url);
}