package com.tencent.qqmusicplayerprocess.qqmusicdlna;
import com.tencent.qqmusicplayerprocess.qqmusicdlna.SonosGroup;
import com.tencent.qqmusicplayerprocess.qqmusicdlna.QPlayDevice;
import com.tencent.qqmusicplayerprocess.qqmusicdlna.IQPlayActionCallback;
import com.tencent.qqmusicplayerprocess.songinfo.SongInfo;

interface IQPlayService {

    /**
     *send search message
     * 
     */
	boolean search();


	/**
     *set volume
     *@param int 
     */
	void setVolume(in int volume);
	

	/**
     * set Network to initialize the new QPlay Device
     *@param LibUpnpDevice device
     *@param String ssid
     *@param String password
     *@param IQPlayActionCallback
     */	
	boolean setNetwork(String udn, in String ssid, in String password, in IQPlayActionCallback actionCallback);
	
	
	/**
     *play
     *@param IQPlayActionCallback 
     */
	boolean play(in IQPlayActionCallback actionCallback);
	
	
	/**
     *pause
     *@param IQPlayActionCallback
     */
	boolean pause(in IQPlayActionCallback actionCallback);
	
	
	/**
     *stop
     *@param IQPlayActionCallback
     */
	boolean stop(in IQPlayActionCallback actionCallback);
	
	
	/**
     *set AVTransportURI
     *@param SongInfo
     *@param IQPlayActionCallback
     */
	boolean setAVTransportURI(in SongInfo songInfo, in IQPlayActionCallback actionCallback);
	
	
	/**
     *seek
     *@param position
     *@param IQPlayActionCallback
     */	
	boolean seek(in long position, in IQPlayActionCallback actionCallback);
	

	/**
     *get Position Info
     *@param IQPlayActionCallback
     */	
	Map getPositionInfo(in IQPlayActionCallback actionCallback);
	

	/**
     *get Transport Info
     *@param IQPlayActionCallback
     */			
	String getTransportInfo(in IQPlayActionCallback actionCallback);
	
	
	/**
     *get Device List
     *@param ArrayList<QPlayDevice>
     */			
	List<QPlayDevice> getDeviceList();
	
	boolean hasCurrentRenderer();	
	void handleVolumeKeyCode(int keyCode);
	boolean isDLNARuning();
	boolean searchAndClearDeviceList();
	boolean getBooleanSharedValue();
	boolean startDLNA();
	boolean stopDLNA();
	void setDlnaTagSharedValue(boolean value);
	boolean isSwitching();
	void notifyStateChanged();
	void handleCurrentDeviceLostUnexpectively();
	boolean isSonosQueue();
	boolean isQPlayQueue();
	String getCurrentRendererUDN();
	void setCurrentRendererDeviceByUDN(String UDN, boolean isAttach, String groupID);
	boolean stopConnectCurrentRenderer();
	QPlayDevice getCurrentDevice();
	
	/*Interface for QueueManager*/
	long getNextSongId(long id);
	List getQPlayPlayList();
	void sendMsgSetTracksInfo(in SongInfo[] songInfos, int currentIndex, int playMode, boolean interrupt);
	void sendMsgSetTrackNum(long songid);
	void sendMsgRemoveTracks();
	void sendMsgPlay();
	void sendMsgSetPlayMode(String playMode);
	boolean isBeyondQueueSize();
	long getLastSongId();
	
	/*Interface for GroupManager*/
	List<SonosGroup> getSonosGroups();
	
	/*Interface for QPlayVolumeController*/
	int getQPlayMaxVolume();
	boolean isQPlayMute();
	int getQPlayVolume();
	
	void setMute(boolean muteValue);
	boolean getMute();

	/*Interface for QPlayService*/
	void setBluetoothAlertSharedValue(boolean value);
	boolean getBluetoothAlertSharedValue();
}