package com.tencent.qqmusicplayerprocess.servicenew;
import com.tencent.qqmusicplayerprocess.songinfo.SongInfo;
import com.tencent.qqmusicplayerprocess.audio.playlist.LastFolderInfo;
import com.tencent.qqmusicplayerprocess.session.Session;
import com.tencent.qqmusic.common.pojo.FolderInfo;
import com.tencent.qqmusicplayerprocess.qplayauto.QPlayAutoContentItem;
import com.tencent.qqmusic.business.user.AuthUser;
import com.tencent.qqmusicplayerprocess.audio.playlist.MusicPlayList;
import com.tencent.qqmusicplayerprocess.audio.playermanager.pathload.SongCacheInfo;
import com.tencent.qqmusiccommon.web.MappedUrl;

interface IMainProcessInterface{
	boolean isAppStarted();
	//For LocalMusicManager
	void saveLastPlayingListParams(boolean isSaveFolderInfoOnly);
	List<SongInfo> loadLocalMusic();
	int getLastPlayListSize();
	List<SongInfo> getLocalSongs();
	int getLocalSongsSize();
	List<SongInfo> getLocalSongsByRange(int startIndex, int endIndex);
	List<SongInfo> getLastPlayingList();
	List<SongInfo> getLastPlayingListPartially(int start, int end);
	LastFolderInfo getLastFolder();
	boolean clearLastPlayingList();
	String checkSongInfoHasLocalFile(in SongInfo songinfo, boolean isIncludeCache);
	SongCacheInfo getLocalSongCacheInfo(in long key);

	/**
	 * 获取缓存文件
	 * @returns null 如果没有找到对应songInfo和bitrate
	 */
	String getCachedSongPath(in SongInfo songInfo, int bitrate);

	//For connectionHelper
	void onSessionReturn(long tipsSession, in long[] blackList, int num);

	//For user manager
	String getWeakQQ();
	String getStrongQQ();
	String getNullQQ();
	boolean isGreen();
	String getAuthToken();
	boolean isWXLogin();
	long getVipLevel();
	int getOfferIdType();

	//For favor manager
	List<SongInfo> getFolderSongAll();

	//For Desk lyric
	// void handlerLyricToOpen();
	// void showDtLyric();
	// void closeDtLyric();

	boolean isUnicomDataUsageFree();
	String replaceUrlByUnicomHostVkeyGuid(String Url);
	String getCdnForUnicom();

	
	
	//For session DB
	//Session readSessionFromDB(in Session session);
	String getUUID();
	String getOpenUdid2();
	void writeSessionToDB(in Session session);

	
	void writePlayLog(String tag, String log);
	
	//For recent list
	oneway void insertSongToRecentyPlayingList(in SongInfo songInfo, boolean replace);
	
	String addSaveWhenPlaySong(in SongInfo songinfo, String playUrl);

	void downloadSong(in SongInfo songInfo,int requestDownloadQuality);
	
	void onMediaUnmounted();

	void updateCanSQDownloadNum(in int canSQDownloadNum);
	
	void updateSongInfo(in SongInfo songinfo,String filename);
	
	Bundle getSingleSongRadioInfo();

	String loadAlbumPath(in SongInfo songinfo, int size);

	boolean isGYLCacheOutOfDate();
	
	void onQPlayAutoDiscover(int ConnectType,String IP, String MAC,int DataPort,int CommandPort,int ResultPort, String name);
	void onConnectMessage(int ConnectStateType);
	void onReceiveCommand(String json);
	List<SongInfo> getLocalMusic();

	List<SongInfo> getFavouriteMusic();
	List<FolderInfo> getFavouriteAlbum();
	List<FolderInfo> getFavouriteMusicList();
	List<SongInfo> getRecentPlayingList();
	List<FolderInfo> getMyFavouriteMusicContent();
	List<SongInfo> getSongsInFolder(long folderID, int folderType);
	void getMusicHallData();
	List<QPlayAutoContentItem> getRecommendList(String parentIDString);
	List<QPlayAutoContentItem> getRankListContent(String parentIDString);
	void requestMusicHallContent(int requestID,String parentIDString, int pageIndex, int pagePerCount);
	List<QPlayAutoContentItem> getRadioList(String parentIDString);
	List<QPlayAutoContentItem> getAssortmentList(String parentIDString);
	void loadAlbumsForQPlay(int requestID,in SongInfo cursonginfo, int packageIndex);
	void receiveRequest(int request);

	void setOverseaStrategy(in String[] strategies);
	int getGuessYouLikeReasonId();
	FolderInfo getMyFavouriteMusicFolder();
	SongInfo getSongInfo(long songId,int type);

	boolean isRecognizing();
	boolean isBaseActivityStarted();

	void deleteSongFileNotExist(in SongInfo songInfo);

	void updateSong(in SongInfo oldSongInfo,in SongInfo newSongInfo,String reason);

	void setLyricBookUrl(String url);
	void setFrom3rdParty(boolean from3rdParty);

	AuthUser getAuthUser();

	// 增加听歌次数
    oneway void increasePlayCount(long songId, int delta);

    // 全局评论,自建歌单和收藏歌单详情Tab入口展示开关
    void setShowComment(int showComment);
    void checkAndShowLocalPush();
    
    void savePrePlayList2DB(boolean isSaveFolderInfoOnly);
    MusicPlayList getPrePlayListFromDB();
    FolderInfo getPrePlayListFolder();
    int getPrePlayListSize();
    List<SongInfo> getPrePlayListByRange(int startIndex, int endIndex);
    List<SongInfo> getPrePlayList();
    boolean isQQMusicBackGround();

    // 专辑是否收藏
    boolean isAlbumCollected(long id);

    // 是否可以播放某个品质的歌曲
    long getCanPlayQualitySwitch();

    // 临时解决vivo读写sp的问题, 下个版本提个技术需求彻底搞定它
    oneway void setPlayInfoStaticsFrom(String from);
    String getPlayInfoStaticsFrom();

    // 7.1 URLProxy
    String getMappedUrl(in String key, in String[] args);

    MappedUrl getMappedUrlWrapper(in String key);
}